confattr.state module — confattr v1.6.0 documentation

# confattr.state module

confattr.state.has_any_config_file_been_instantiated = False

  This is set when instantiating a `ConfigFile`. Trying to change a `key` when this flag is set will raise a `TimingError`.

confattr.state.has_config_file_been_instantiated = False

  This is set when instantiating a `ConfigFile` without passing `config_instances`, i.e. one that should support all settings. Trying to create a `Config` when this flag is set will raise a `TimingError`.